/* Argument checker for rm */
#include <stdio.h>
#include <string.h>

char *progname = "chmod";


/*D

  ptchmod - SUT chmod

Description:

ptchmod changes the permissions of a list of files on specified hosts.

Command Line Arguments:

ptchmod [-m <machine_file>|-M <machine_list>] [-Rf] mode <file1> [<file2> <file3>...]

.N machine_args

. -R - change permissions recursively
. -f - suppress error messages
. mode - an octal mode or symbolic mode list as used by chmod(1)
- <file1> [<file2> <file3>...] - the list of files to repermission

Environment Variables:

.N machine_envs

Examples:

To change allow the owner of a file "myscript.sh" to execute it on the machines
specified in the file "destination_machines" use

.vb
ptchmod -m destination_machines u+x myscript.sh
.ve

To make the same change, specifying the machines on the command line, use

.vb
ptchmod -M "host1 host2 host3" u+x myscript.sh
.ve

To change the permissions on all files and directories starting with 'p' 
in directory "/home/johndoe/project" to have permissions rwxr--r--, use

.vb
ptchmod -m destination_machines -R 744 "/home/johndoe/project/p*"
.ve

.seealso chmod(1)

    D*/
int check_args(int argc, char *argv[])
{
    int i, j;
    char *start = NULL, *tmp = NULL;

    if (argc < 3)
        return -1;

    for (i = 1; i < argc; i++){
        if (strcmp(argv[i], "-f") == 0)
            continue;
        if (strcmp(argv[i], "-R") == 0)
            continue;
        if (strcmp(argv[i], "-fR") == 0)
            continue;
        if (strcmp(argv[i], "-Rf") == 0)
            continue;
        /* can't be an option */

        /* could be a symbolic mode */
        start = argv[i];
        do {
            if ((tmp = strchr(start, '-')) != NULL ||
                    (tmp = strchr(start, '+')) != NULL ||
                    (tmp = strchr(start, '=')) != NULL ){
                if (strspn(start, "ugoa") != (tmp-start))
                    return -1;
                tmp += strspn(tmp + 1, "rwxXst") + 1;
                if (*tmp != '\0'){
                    if (*tmp == ','){
                        start = tmp+1;
                        continue;
                    } else {
                        return -1;
                    }
                }
                break;
            } else break;
        } while (1);

                    /* must be an octal mode */
                    if (tmp == NULL && sscanf(argv[i], "%o", &j) != 1)
                        return -1;
                    break;
    }

    /* Make sure no options are in 
       with the filenames*/
    for (; i < argc; i++){
        if (argv[i][0] == '-')
            return -1;
    }

    return 0;
}
